sequencetools.is_strictly_increasing_sequence
=============================================

.. autofunction:: abjad.tools.sequencetools.is_strictly_increasing_sequence.is_strictly_increasing_sequence
